@@ -56,7 +56,16 @@ compare <- function(w,n.best=50,tol=10E-6,verbose=FALSE) {
         }    
         Ph.Init <- comb.ger(phase.init)
         Rf.Init <- comb.ger(rf.init)
-        
+        if(nrow(Ph.Init)>1){
+          ##Removing ambigous phases
+          rm.ab<-rem.amb.ph(M=Ph.Init, w=w, seq.num=all.ord[i,])
+          Ph.Init <- Ph.Init[rm.ab,]
+          Rf.Init <- Rf.Init[rm.ab,]
+          if(class(Ph.Init)=="integer"){
+            Ph.Init<-matrix(Ph.Init,nrow=1)
+            Rf.Init<-matrix(Rf.Init,nrow=1)
+          }
+        }
         for(j in 1:nrow(Ph.Init)){
                                         # estimate parameters
           final.map <- est.map.c(geno=get(w$data.name)$geno[,all.ord[i,]],
@@ -105,7 +114,16 @@ compare <- function(w,n.best=50,tol=10E-6,verbose=FALSE) {
         }    
         Ph.Init <- comb.ger(phase.init)
         Rf.Init <- comb.ger(rf.init)
-        
+        if(nrow(Ph.Init)>1){
+          ##Removing ambigous phases
+          rm.ab<-rem.amb.ph(M=Ph.Init, w=w, seq.num=all.ord[i,])
+          Ph.Init <- Ph.Init[rm.ab,]
+          Rf.Init <- Rf.Init[rm.ab,]
+          if(class(Ph.Init)=="integer"){
+            Ph.Init<-matrix(Ph.Init,nrow=1)
+            Rf.Init<-matrix(Rf.Init,nrow=1)
+          }
+        }
         for(j in 1:nrow(Ph.Init)){
                                         # estimate parameters
           final.map <- est.map.c(geno=get(w$data.name)$geno[,all.ord[i,]],
